<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-medias?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// M
	'medias_description' => 'Gestioun dei media de SPIP',
	'medias_slogan' => 'Gestioun dei media en SPIP',
];
